/*
* Calculator Buttons + Select based on:
* http://stackoverflow.com/questions/6097240/javascript-on-ios-opening-an-html-select-element
*/

function CalculatorController($scope, $routeParams, ISOLookup){

	var units = $routeParams.system;

	//temp variables for the calculation
	var mgL4c, mgL6c, mgL14c, cmgL4c, cmgL6c, cmgL14c, mg4c, mg6c, mg14c, cmg4c, cmg6c, cmg14c, gms4c, gms6c, gms14c, cgms4c, cgms6c, cgms14c;

	function init(){
		$scope.volumeLabel = ( units == 'metric' ) ? 'L' : 'gal';
		$scope.massLabel = ( units == 'metric' ) ? 'kg' : 'lbs';

		$scope.flowOptions = [];
		if( units == 'metric' ){
			for(var i = 20; i<401; i += 20){ $scope.flowOptions.push(i); }
			for(var i = 480; i<1601; i += 80){ $scope.flowOptions.push(i); }
			for(var i = 1800; i<4001; i += 200){ $scope.flowOptions.push(i); }
		} else {
			for(var i = 5; i<100; i += 5){ $scope.flowOptions.push(i); }
			for(var i = 100; i<400; i += 20){ $scope.flowOptions.push(i); }
			for(var i = 400; i<1001; i += 50){ $scope.flowOptions.push(i); }
		}

		$scope.hourOptions = [];
		for( var i = 1; i < 25; i++){
			$scope.hourOptions.push(i);
		}

		$scope.isoOptions = [];
		for( var i=5; i < 29; i++ ){
			var data = {
				label: i.toString(10),
				value:i
			}
			$scope.isoOptions.push(i);
		}

		$scope.reset();

	}

	$scope.reset = function (){
		//results
		$scope.currentMass = 0;
		$scope.targetMass = 0;
		$scope.reduction = 0;
		$scope.percentReduction = 0;
		$scope.reductionFactor = 0;

		//readings
		$scope.hours = 24;
		$scope.current4 = 19;
		$scope.current6 = 17;
		$scope.current14 = 14;
		$scope.target4 = 13;
		$scope.target6 = 11;
		$scope.target14 = 8;
		$scope.flow = ( units == 'metric' ) ? 100 : 25;
	};

	//Perform calculations common to U.S. and metric units
	var baseCalc = function(){
		//get ISO code 4406-1999 particles/mL values and put them into count... variables (target)
		//TODO check if these are correct; the original app used '$scope.target4' for all three of the next lines!!!
		var targetRealISO4 = ISOLookup.isoConvert($scope.target4);
		var targetRealISO6 = ISOLookup.isoConvert($scope.target6);
		var targetRealISO14 = ISOLookup.isoConvert($scope.target14);

		//get ISO code 4406-1999 particles/mL values and put them into ccount... variables (current)
		var currentRealISO4 = ISOLookup.isoConvert($scope.current4);
		var currentRealISO6 = ISOLookup.isoConvert($scope.current6);
		var currentRealISO14 = ISOLookup.isoConvert($scope.current14);

		//divide counts by particles/mL in mg/L of solution, multiply by SRM 2806 NIST approved dust distribution level of 2.8 to get Mg/L equivalents (target)
		mgL4c = (targetRealISO4/6095)*2.8;
		mgL6c = (targetRealISO6/2395)*2.8;
		mgL14c = (targetRealISO14/170.4)*2.8;

		//divide ccounts by particles/mL in mg/L of solution, multiply by SRM 2806 NIST approved dust distribution level of 2.8 to get Mg/L equivalents (current)
		cmgL4c = (currentRealISO4/6095)*2.8;
		cmgL6c = (currentRealISO6/2395)*2.8;
		cmgL14c = (currentRealISO14/170.4)*2.8;

		var flowRateInGallons = ( units == 'metric' ) ? $scope.flow * 0.264172052 : $scope.flow;

		//find total mg/year for specific count values (target)
		mg4c = mgL4c * flowRateInGallons * 3.785 * 60 * $scope.hours * 360;
		mg6c = mgL6c * flowRateInGallons * 3.785 * 60 * $scope.hours * 360;
		mg14c = mgL14c * flowRateInGallons * 3.785 * 60 * $scope.hours * 360;

		//find total mg/year for specific count values (current)
		cmg4c = cmgL4c * flowRateInGallons * 3.785 * 60 * $scope.hours * 360;
		cmg6c = cmgL6c * flowRateInGallons * 3.785 * 60 * $scope.hours * 360;
		cmg14c = cmgL14c * flowRateInGallons * 3.785 * 60 * $scope.hours * 360;

		//find gms/year for specific count values (target)
		gms4c = mg4c/1000;
		gms6c = mg6c/1000;
		gms14c = mg14c/1000;

		//find gms/year for specific count values (current)
		cgms4c = cmg4c/1000;
		cgms6c = cmg6c/1000;
		cgms14c = cmg14c/1000;
	};

	var calculateMetric = function(){
		//find kilograms/year for specific count values
		var kg4c = gms4c/1000;
		var kg6c = gms6c/1000;
		var kg14c = gms14c/1000;
		$scope.targetMass = kg4c;

		//find kilograms/year for specific count values
		var ckg4c = cgms4c/1000;
		var ckg6c = cgms6c/1000;
		var ckg14c = cgms14c/1000;
		$scope.currentMass = ckg4c;

		//find reduction amount for 4c
		$scope.reduction = ckg4c - kg4c;

		//find percent reduction amount for 4c
		$scope.percentReduction = 100 - ((kg4c/ckg4c) * 100);

		//find reduction factor amount for 4c
		$scope.reductionFactor = ckg4c/kg4c;
	};

	var calculateImperial = function(){
		//find lbs/year for specific count values (target)
		var lbs4c = (gms4c/1000) * 2.2;
		var lbs6c = (gms6c/1000) * 2.2;
		var lbs14c = (gms14c/1000) * 2.2;
		$scope.targetMass = lbs4c;

		//find lbs/year for specific count values (current)
		var clbs4c = (cgms4c/1000) * 2.2;
		var clbs6c = (cgms6c/1000) * 2.2;
		var clbs14c = (cgms14c/1000) * 2.2;
		$scope.currentMass = clbs4c;

		//find reduction amount for 4c
		$scope.reduction = clbs4c - lbs4c;

		//find percent reduction amount for 4c
		$scope.percentReduction = 100 - ((lbs4c/clbs4c) * 100);

		//find reduction factor amount for 4c
		$scope.reductionFactor = clbs4c/lbs4c;
	};

	$scope.calculate = function(){
		baseCalc();
		if( units == 'metric' ){
			calculateMetric();
		} else {
			calculateImperial();
		}
	};

	init();

}